@@ -38,6 +38,7 @@
 
 //#define DEBUG_1
 //#define DEBUG_2
+//#define DEBUG_3
 
 //Html_Widget::Html_Widget(QWidget *parentWidget, QObject *parent, GUIProfile prof)
 //	: KHTMLPart(parentWidget, parent, prof)
@@ -128,8 +129,8 @@ void Html_Widget::contextMenuEvent(QContextMenuEvent *event)
 	menu->addAction(findAct);
 	menu->addAction(pageAction(QWebPage::CopyLinkToClipboard));
 	//menu->addAction(pageAction(QWebPage::OpenLinkInNewWindow));		//ooo
-	#if QT_VERSION >= 0x040501
-		menu->addAction(pageAction(QWebPage::SelectAll));		//ooo   Qt 4.5.1
+	#if QT_VERSION >= 0x040500
+		menu->addAction(pageAction(QWebPage::SelectAll));		//ooo   Qt 4.5.0
 	#endif
 	menu->exec(mapToGlobal(event->pos()));
 
@@ -250,21 +251,34 @@ void Html_Widget::setOut(QString S)	//ooo
 		clear();
 		return;
 	}
+	
+	S = "<!DOCTYPE HTML PUBLIC ""-//W3C//DTD HTML 4.0 Transitional//EN"">"			//ooo
 	//S = "<html>\n<style type=""text/css""><!-- i {color: blue} "
-	S = "<html>\n<style type=""text/css""><!-- i {color: "+sentencePartTxtColor+"} "	//ooo
+	/*S =*/ "<html>"											//ooo
+		 "<style type=""text/css""><!-- "							//ooo
+		//"span.foreground {color: #ff0000} "							//ooo
+		"i {color: "+sentencePartTxtColor+"} "							//ooo
+		//"FONT {font-size: 12 pt}"								//ooo
+		//"FONT[SIZE~='-1'] {font-size: 12 pt}"							//ooo
+		"FONT[SIZE~='-1'] {font-size: "+QString::number(Size-1)+" pt}"				//ooo
+		"FONT[SIZE~='-2'] {font-size: "+QString::number(Size-2)+" pt}"				//ooo
+		//"abr {color: red} "									//ooo	StarDict
 		//"l {color: black} "	//ooo
-		"l {color: "+expressionTxtColor+"} "	//ooo
-		"body {font-family: "+fontName+";background: "+bgColor+"; color: "+txtColor+";"
-		"font-style: "+fontStyle+"; font-weight: "+fontWeight+";"					//ooo
+		"l {color: "+expressionTxtColor+"} "							//ooo
+		"k {color: "+expressionTxtColor+"} "							//ooo	StarDict
+		"body {font-family: "+fontName+"; background: "+bgColor+"; color: "+txtColor+"; "
+		"font-style: "+fontStyle+"; font-weight: "+fontWeight+"; "				//ooo
 		"font-size: "+QString::number(Size)+"pt}"
 		"p {margin: 0 0 0 0}"
 		"p.text {margin: 0 0 0 1.2em; text-indent: -1.2em}"
 		"hr {width: 25%}"
 		//"a:link {color: black}"
-		"a:link {color: "+expressionTxtColor+"}"	//ooo
+		"a:link {color: "+expressionTxtColor+"}"						//ooo
 		//"a:visited {color: black}--></style>\n"
-		"a:visited {color: "+expressionTxtColor+"}--></style>\n"	//ooo
-		"<meta http-equiv=""Content-Type"" content=""text/html; charset="+Charset+""">"
+		"a:visited {color: "+expressionTxtColor+"}--></style>\n"				//ooo
+		//"<meta http-equiv=""Content-Type"" content=""text/html; charset="+Charset+""">"
+		//"<meta http-equiv=""Content-Type"" content=""text/html; charset="+Charset+""">"		//ooo
+		//"</head><body>"									//ooo
 		"<body>"
 		+S+
 
@@ -272,15 +286,23 @@ void Html_Widget::setOut(QString S)	//ooo
 		/*S3+*/unicodeString3+   //ooo
 	#endif
 
-		"</body></html>";
+		//"</body></html>";
+		"</body>"										//ooo
+	    "</html>";											//ooo
 	//setEncoding(Charset);
 
 		//setCharset(Charset);
 		//setCharset(Charset,true);
 	//begin();
 	//write(S);
-	setHtml(S);	//ooo
+	setHtml(S);		//ooo
+	//toHtml();		//ooo
 	//end();
+	
+	#ifdef DEBUG_3
+		//std::cout << "this->toHtml(): " << this->toHtml().toAscii().data() << "\n";
+		std::cout << "\n*** >>> S: " << S.toAscii().data() << "\n";
+	#endif
 
 #ifdef DEBUG_1
 	ofstream file;
@@ -319,6 +341,9 @@ void Html_Widget::setFont(QString family, int pointSize, QFont::Style fontStyle_
 {
 	fontName = family;
 	Size = pointSize;
+	Size_less1 = pointSize-1;	//ooo
+	//Size_less1 = 2;		//ooo
+	Size_less2 = pointSize-2;	//ooo
 
 #ifdef DEBUG_2   //ooo
 	qDebug() << "fontStyle_ = " << fontStyle_;
