@@ -33,9 +33,13 @@
 #include <QMessageBox>
 #include <KLocale>
 #include <QDebug>	//ooo
+#include <QUrl>		//ooo
+#include <QDir>		//ooo
 
 #include <iostream>	//ooo
 #include <stdlib.h>	//ooo
+#include <zlib.h>	//ooo
+#include <stdio.h>	//ooo
 
 #include "babylon_bgl.h"
 
@@ -43,13 +47,29 @@
 //#define DEBUG_2
 //#define DEBUG_3
 //#define DEBUG_3a
+//#define DEBUG_3a_
+//#define DEBUG_3b
+//#define DEBUG_3h
+//#define DEBUG_3p
 //#define DEBUG_4
 //#define DEBUG_5
 
 
-Babylon_bgl::Babylon_bgl(QString filename)
+Babylon_bgl::Babylon_bgl(QString filename, QString strIndexDir)
 {
 	m_filename = filename.toAscii().data();
+
+	//ba = filename.toStdString().c_str();
+
+	//ba = QByteArray(filename.toAscii().data());
+	//ba = filename.toAscii();
+	//ba = "/home/gons/.qtrans/index";
+	//ba = filename.toUtf8();
+	ba = filename.toAscii();
+	 //h_filename = filename.toUtf8().toHex().data();
+	//h_filename = ba.toHex().data();
+	m_qstrIndexDir = strIndexDir;
+	m_strIndexDir = strIndexDir.toAscii().data();
 }
 
 Babylon_bgl::~Babylon_bgl()
@@ -313,9 +333,11 @@ bgl_entry Babylon_bgl::readEntry()
 	}
 
 	bgl_block block;
-	uint len, pos;
+	//uint len, pos;
+	unsigned int len, pos;			//ooo
 	std::wstring headword;
 	std::wstring definition;
+	std::wstring definition_stack = L"";	//ooo
 	std::wstring definition_origin = L"";	//ooo
 	std::wstring temp;
 	std::vector<std::wstring> alternates;
@@ -326,7 +348,42 @@ bgl_entry Babylon_bgl::readEntry()
 	const std::wstring toFind = L"être"; //L"Acheulian";
 	const std::wstring toFind_x2 = L"1,500,000";
 	std::wstring transcription = L"";
+	//std::wstring filename = L"";
+	std::string filename = "";
+	std::string filename_2 = "";	//ooo
 	std::wstring::size_type n = 0;
+	QCryptographicHash hash( QCryptographicHash::Md5 );
+	std::string hash_str = "";
+	unsigned char const * data;
+	size_t size;
+	std::vector < unsigned char > compressedData( compressBound( size ) );
+	unsigned long compressedSize;
+	//char const *indexFile = "myFile";
+	//File::Class idx( indexFile, "w" );
+	//FILE *fopen( indexFile, "w" );
+	FILE *fp;
+	QUrl url;
+	std::string url_str;
+	QDir dir;			//ooo
+	QDir hashDir;			//ooo
+	bool dirWasCreated = false;	//ooo
+	
+	hash.reset();					//ooo
+	hash.addData( ba );				//ooo
+	hash_str = hash.result().toHex().data();	//ooo
+	
+	//QString str_ = "/home/gons/.qtrans/index/" + hash.result().toHex();	//ooo
+	QString strHashDir = m_qstrIndexDir + "/" + hash.result().toHex();	//ooo
+	
+	//dir = QDir("/home/gons/.qtrans/index/");	//ooo
+	dir = QDir(m_qstrIndexDir);	//ooo
+	//dir_2 = QDir(str_);				//ooo
+	hashDir = QDir(strHashDir);			//ooo
+				
+	if (!hashDir.exists()) {			//ooo
+		dir.mkpath( hash.result().toHex() );
+		dirWasCreated = true;
+	}
 
 
 	while( readBlock( block ) )
@@ -338,6 +395,94 @@ bgl_entry Babylon_bgl::readEntry()
 
 		switch( block.type )
 		{
+			//case 1:
+			case 2:
+
+				pos = 0;
+
+				#ifdef DEBUG_3b
+					std::wcout << "\n222\n";
+					std::wcout << "block.data[" << pos << "] = " << block.data[pos] << "\n";
+				#endif
+
+
+				len = (unsigned char)block.data[pos++];
+
+				//std::string filename( block.data+pos, len );
+
+				/*for ( unsigned int i = (pos+3); i < (pos+3+length); i++) {
+					 transcription += block.data[i];
+				}*/
+				
+
+				for ( unsigned int i = pos; i < pos + len; i++) {
+
+					#ifdef DEBUG_3b
+						std::wcout << "block.data[" << i << "] = " << block.data[i] << "\n";
+					#endif
+
+					 filename += block.data[i];
+				}
+
+				#ifdef DEBUG_3b
+					//std::wcout << "filename = " << filename << "\n";
+					std::cout << "filename = " << filename << "\n";
+				#endif
+
+				pos += len;
+
+				/*unsigned char const * data = &block.data[pos];
+				size_t size = block.length - pos;
+
+				std::vector< unsigned char > compressedData( compressBound( size ) );
+
+				unsigned long compressedSize = compressedData.size();*/
+
+				data = &block.data[pos];
+				size = block.length - pos;
+
+				//compressedData.size() = compressBound(size);
+
+				compressedSize = compressedData.size();
+
+				#ifdef DEBUG_3p
+					//FILE *fp = fopen(filename.c_str(), "w");
+					fp = fopen(filename.c_str(), "w");
+					//fwrite(block.data + pos, 1, block.length -pos, fp);
+					//fwrite(&compressedData.front(), 1, size, fp);
+					fwrite(&block.data[pos], 1, size, fp);
+					fclose(fp);
+				#endif
+				
+
+				if (dirWasCreated) {	//ooo
+					//filename_2 = "/home/gons/.qtrans/index/" + hash_str + "/" + filename;
+					 filename_2 = std::string(m_qstrIndexDir.toAscii().data()) + "/" + hash_str + "/" + filename;
+					//filename_2 = m_strIndexDir + "/" + hash_str + "/" + filename;
+					
+					/*filename_2 = m_strIndexDir;
+					filename_2 += "/";
+					filename_2 += hash_str;
+					filename_2 += "/";
+					filename_2 += filename;
+					*/
+					fp = fopen(filename_2.c_str(), "w");
+					fwrite(&block.data[pos], 1, size, fp);
+					fclose(fp);
+				}
+				
+				//filename = L"";
+				filename = "";
+
+				/*if (filename == "D437C11D.bmp") {
+
+					#ifdef DEBUG_3b
+						std::cout << "***   D437C11D.bmp" << "\n";
+					#endif
+
+				}*/
+
+				break;
 			case 1:
 			case 10:
 
@@ -364,28 +509,46 @@ bgl_entry Babylon_bgl::readEntry()
 
 				//j = headword.find("black");
 
-				//if (j >= 0) {	//ooo
-					#ifdef DEBUG_3
-						printf("Headword : %s\n", headword.c_str());
-						//printf("Definition to ...: %s\n", entry.definition.c_str());
-						//printf("Definition to ...: %s\n", "	*****");
-					#endif
-				//}
+				#ifdef DEBUG_3a
+					std::cout << "\n......................\n";
+					std::wcout << "block.data[" << pos << "] = " << block.data[pos] << "\n";
+					std::wcout << "block.data[" << pos+1 << "] = " << block.data[pos+1] << "\n";
+					std::wcout << "block.data[" << pos+2 << "] = " << block.data[pos+2] << "\n";
+					//printf("Headword : %s\n", headword.c_str());
+					//printf("Definition to ...: %s\n", entry.definition.c_str());
+					//printf("Definition to ...: %s\n", "	*****");
+				#endif
 
 				// Definition
 				len = 0;
 				len = (unsigned char)block.data[pos++] << 8;
+				//pos++;						//ooo
+				//len = (unsigned char)block.data[pos++];		//ooo
+
+				#ifdef DEBUG_3a
+					std::wcout << "len = " << len << "\n";
+				#endif
+
+				//len <<= 8;					//ooo
+
+				#ifdef DEBUG_3a
+					std::wcout << "len = " << len << "\n";
+				#endif
+
 				len |= (unsigned char)block.data[pos++];
 				definition.reserve( len );
 
 				#ifdef DEBUG_3a
-					std::cout << "\n......................\n";
+					//std::cout << "\n......................\n";
 					std::wcout << "headword = " << headword << "\n";
 					std::wcout << "len = " << len << "\n";
 				#endif
 
 				for(uint a=0;a<len;a++)
 				{
+					#ifdef DEBUG_3a_
+						std::wcout << "block.data[" << pos << "] = " << block.data[pos] << " a = " << a << "\n";
+					#endif
 
 					#ifdef DEBUG_3a
 						//qDebug() << "   for(uint a=0;a<len;a++) --- a = " << a;
@@ -395,7 +558,7 @@ bgl_entry Babylon_bgl::readEntry()
 							std::wcout << "block.data[" << pos << "] = " << block.data[pos] << "\n";
 						}*/
 
-						std::wcout << "block.data[" << pos << "] = " << block.data[pos] << " a = " << a << "\n";
+						//std::wcout << "block.data[" << pos << "] = " << block.data[pos] << " a = " << a << "\n";
 
 						definition_origin += block.data[pos];
 
@@ -412,6 +575,11 @@ bgl_entry Babylon_bgl::readEntry()
 
 					} else if ( (unsigned char)block.data[pos] == 0x06 ) {
 
+						#ifdef DEBUG_3a
+							std::wcout << "block.data[" << pos+1 << "] = " << block.data[pos+1] << "\n";
+							std::wcout << "block.data[" << pos+2 << "] = " << block.data[pos+2] << "\n";
+						#endif
+
 						pos += 2;
 						a++;
 
@@ -442,7 +610,8 @@ bgl_entry Babylon_bgl::readEntry()
 						}
 
 						#ifdef DEBUG_5
-							definition += L"(??)";
+							definition += std::wstring( L"(\?\?)" )
+							//definition += L"(??)";
 						#endif
 
 						pos += length + 2;
@@ -509,6 +678,32 @@ bgl_entry Babylon_bgl::readEntry()
 						pos += length + 2;
 						a += length + 1;
 
+					/*} else if ( ((unsigned char)block.data[pos] >= 0x41 && (unsigned char)block.data[pos] <= 0x5A &&
+							(unsigned char)block.data[pos+1] == 0x10)
+							|| ((unsigned char)block.data[pos] >= 0x41 && (unsigned char)block.data[pos] <= 0x5A &&
+							(unsigned char)block.data[pos+1] >= 0x41 && (unsigned char)block.data[pos+1] <= 0x5A &&
+							(unsigned char)block.data[pos+2] == 0x10) ) {
+
+						// heb->eng
+						pos += len - a;
+						//a += len - a;
+						break;*/
+
+					} else if ( (unsigned char)block.data[pos] >= 0x41 && (unsigned char)block.data[pos] <= 0x5A &&
+							(unsigned char)block.data[pos+1] == 0x10 ) {
+
+						// heb->eng
+						pos += len - a;
+						a += len - a;
+						break;
+
+					} else if ( (unsigned char)block.data[pos] == 0x1A && (unsigned char)block.data[pos] >= 0x03 ) {
+
+						// heb->eng
+						pos += len - a;
+						a += len - a;
+						break;
+
 					} else if ( (unsigned char)block.data[pos] == 0x50 && (unsigned char)block.data[pos + 1 ] == 0x1B &&
 							len - a - 1 >= 2 ) {
 
@@ -523,7 +718,21 @@ bgl_entry Babylon_bgl::readEntry()
 						}
 
 						definition = L"[" + std::wstring( L"<span class=\"bgltrn\">" ) + transcription + L"</span>" + L"] " + definition;
-
+						
+						/*definition_stack = L"[";
+						definition_stack += L"<span class=\"bgltrn\">";
+						definition_stack += transcription;
+						definition_stack += L"</span>";
+						definition_stack += L"]";
+						definition.insert(0,definition_stack);
+						*/
+						
+						/*definition.insert(0,L"]");
+						definition.insert(0,L"</span>");
+						definition.insert(0,transcription);
+						definition.insert(0,L"<span class=\"bgltrn\">");
+						definition.insert(0,L"[");
+						*/
 						pos += length + 3;
 						a += length + 2;
 
@@ -545,9 +754,84 @@ bgl_entry Babylon_bgl::readEntry()
 
 						definition = L"[" + std::wstring( L"<span class=\"bgltrn\">" ) + transcription + L"</span>" + L"] " + definition;
 
+						/*definition_stack = L"[";
+						definition_stack += L"<span class=\"bgltrn\">";
+						definition_stack += transcription;
+						definition_stack += L"</span>";
+						definition_stack += L"]";
+						//definition.insert(0,definition_stack);
+						
+						definition = definition_stack + definition;
+						*/
+						
+						/*definition.insert(0,L"]");
+						definition.insert(0,L"</span>");
+						definition.insert(0,transcription);
+						definition.insert(0,L"<span class=\"bgltrn\">");
+						definition.insert(0,L"[");
+						*/
 						pos += length + 4;
 						a += length + 3;
 
+					} else if ( (unsigned char)block.data[pos] == 0x1E ) {
+
+						
+						//QCryptographicHash *crypt = new QCryptographicHash(QCryptographicHash::Md5); 
+
+						//QByteArray string = x.toStdString().c_str();
+						//crypt->addData(ba);
+
+						//hash.reset();
+						//hash.addData( ba );
+
+						//hash_str = hash.result().toHex().data();
+
+						#ifdef DEBUG_3h
+							std::cout << "hash_str = " << hash_str << "\n";
+						#endif
+
+						/*++pos;
+
+						while ( (unsigned char)block.data[pos] != 0x1F ) {
+							filename += block.data[pos++];
+						}*/
+
+						url.setScheme( "bres" );
+						//url.setHost( QString::fromUtf8( getId().c_str() ) );
+						url.setHost( QString::fromUtf8( "/home/gons/.qtrans/index" ) );
+
+						//url.setPath( QString::fromUtf8( filename.c_str() ) );
+						//url.setPath( QString::fromUtf8( filename.c_str() ) );
+
+						url_str = url.toEncoded().data();
+
+						//ba = hash(ba, QCryptographicHash::Md5);
+
+						//definition += L"bres:///usr/share/trans/babylon/Concise_Oxford_English_Diction.BGL/";
+						//definition += std::wstring( L"bres://" ) + std::wstring(h_filename.begin(), h_filename.end()) + L"/";
+						//definition += std::wstring( L"bres://" ) + std::wstring(hash_str.begin(), hash_str.end()) + L"/";
+						//definition += std::wstring(url_str.begin(), url_str.end()) + L"/";
+						//definition += std::wstring( L"file://" ) + std::wstring( L"/home/gons/.qtrans/index" ) + L"/";
+						//definition += std::wstring( L"file://" ) + std::wstring( L"/home/gons/.qtrans/index/" ) + std::wstring(hash_str.begin(), hash_str.end()) + L"/";
+						//definition += std::wstring( L"file://" ) + std::wstring((std::string(m_qstrIndexDir.toAscii().data())).begin(), (std::string(m_qstrIndexDir.toAscii().data())).end()) + L"/" + std::wstring(hash_str.begin(), hash_str.end()) + L"/";
+						//definition += std::wstring( L"file://" ) + std::wstring(std::string(m_qstrIndexDir)) + L"/" + std::wstring(hash_str.begin(), hash_str.end()) + L"/";
+						 //definition += std::wstring( L"file://" ) + std::wstring(m_strIndexDir.begin(), m_strIndexDir.end()) + L"/" + std::wstring(hash_str.begin(), hash_str.end()) + L"/";
+						//definition += std::wstring( L"bres://" ) + std::wstring(crypt->result().data().begin(), crypt->result().data().end()) + L"/";
+						
+						definition += L"file://";
+						definition += std::wstring(m_strIndexDir.begin(), m_strIndexDir.end());
+						definition += L"/";
+						definition += std::wstring(hash_str.begin(), hash_str.end());
+						definition += L"/";
+						
+						++pos;
+
+					} else if ( (unsigned char)block.data[pos] == 0x1F ) {
+
+						//definition += std::wstring( L"\" alt=\"Grafik" );
+						//pos += 2;
+						++pos;
+
 					} else if ( (unsigned char)block.data[pos] < 0x20 ) {	//SP: Space
 
 						#ifdef DEBUG_2
@@ -556,6 +840,11 @@ bgl_entry Babylon_bgl::readEntry()
 
 						if ( a <= /*<*/ len - 3 && block.data[pos] == 0x14 && block.data[pos+1] == 0x02 ) {
 
+							#ifdef DEBUG_3a
+								std::wcout << "block.data[" << pos+1 << "] = " << block.data[pos+1] << "\n";
+								std::wcout << "block.data[" << pos+2 << "] = " << block.data[pos+2] << "\n";
+							#endif
+
 							//definition = partOfSpeech[(unsigned char)block.data[pos+2] - 0x30] + " " + definition;
 							definition = partOfSpeech[(unsigned char)block.data[pos+2] - 0x30] + L" " + definition;	//ooo
 
@@ -625,16 +914,19 @@ bgl_entry Babylon_bgl::readEntry()
 							}*/
 						#endif
 
-						/*if (block.data[pos] == 0x96) {		//ooo but eng->jpn problem
+						if (block.data[pos] == 0x96 && ( (block.data[pos+1] >= 0x30 && block.data[pos+1] <= 0x39) ||
+							(block.data[pos+1] >= 0x41 && block.data[pos+1] <= 0x5A) ||
+							(block.data[pos+1] >= 0x61 && block.data[pos+1] <= 0x7A))) {	//ooo but eng->jpn problem
+
 							definition += 0x2D;		// "-"
 							pos++;
 						} else {
 
 							definition += block.data[pos++];
 
-						}*/
+						}
 
-						definition += block.data[pos++];
+						//definition += block.data[pos++];
 
 						#ifdef DEBUG_1
 							//qDebug() << "definition = " << block.data[pos+1];
@@ -764,7 +1056,7 @@ bgl_entry Babylon_bgl::readEntry()
 					}*/
 
 					std::wcout << "\ndefinition_origin = " << definition_origin << "\n";
-					std::wcout << "\entry.headword = " << entry.headword << "\n";
+					std::wcout << "entry.headword = " << entry.headword << "\n";
 					std::wcout << "entry.definition = " << entry.definition << "\n";
 					std::cout  << "   *****\n";
 
