@@ -50,6 +50,7 @@
 #include <QStatusBar>		//ooo
 #include <QTime>		//ooo
 #include <QProgressBar>		//ooo
+#include <QDir>			//ooo
 
 #include "systemtray.h"
 #include "settings_widg.h"
@@ -67,7 +68,7 @@
 
 //class QComboBox;
 
-class QTrans : public KMainWindow
+class QTrans : public QMainWindow
 {
     Q_OBJECT
 public:
@@ -83,6 +84,8 @@ public slots:
 	void Popup();
 
 	void slot_Quit();
+	void slot_Left();			//ooo
+	void slot_Right();			//ooo
 	void slot_Exit(bool ask = true);
 	void slot_Ok();
 	void slot_About();
@@ -93,6 +96,7 @@ public slots:
 	void slot_ShortCut();
 	void toggleMode();
 	void slot_OnTop();
+	void slot_Alternates();			//ooo
 	void slot_WordStartsWith();		//ooo
 	void slot_WholeWordsOnly();		//ooo
 	void slot_Combo(const QString &);
@@ -103,6 +107,7 @@ public slots:
 	void chooseLibrary(QAction *action);
 	void slot_searchInAllDictionaries();	//ooo
 	void slot_searchInEveryDictionary();	//ooo
+	void slot_LookUpInWholeDictionary();	//ooo
 	void slot_statusBarMessage();		//ooo
 	void slot_aboutKDE();
 	void slot_Config();
@@ -117,6 +122,7 @@ public:
 	void Translate(QString ,int ind=0, bool allDict=false, bool inEveryDict=false);	//ooo
 	void readConfig();
 	void writeConfig();
+	void writeConfig_2();
 	void Default();
 
 	SystemTray *Dock;
@@ -126,7 +132,10 @@ public:
 	QString Prev_Clip;
 
 	KAction *closeAct;
+	KAction *leftAct;		//ooo
+	KAction *rightAct;		//ooo
 	KToolBar *ToolBar;
+	//QStatusBar *statusBar_;	//ooo
 	KHelpMenu *HelpMenu;
 
 	QTimer *Time;
@@ -135,7 +144,14 @@ public:
 	int NumOfLines;			//ooo
 	int SearchTime;			//ooo
 	int FinishedTime;		//ooo
-	QString DictionaryName;	//ooo
+	QString DictionaryName;		//ooo
+	QDir homeDir;			//ooo
+	QDir qtransDir;			//ooo
+	QDir indexDir;			//ooo
+	QString strQtransDir;		//ooo
+	QString strIndexDir;		//ooo
+	QList<QString> list;		//ooo
+	int leftRightCounter;		//ooo
 
 	QList<Dictionary> *bab_dict;
 	QWebView *view;
@@ -161,7 +177,10 @@ public:
 		wordStartsWith,		//ooo
 		wordContains,		//ooo
 		wordEndsWith,		//ooo
-		wholeWordsOnly;		//ooo
+		wholeWordsOnly,		//ooo
+		wholeStarDict,		//ooo
+		enableAlternates,	//ooo
+		clipHasChanged;		//ooo
 	/*-- --*/
 
 	QFont fontType;
@@ -199,10 +218,12 @@ private:
 	QAction *normalModeAct;
 	QAction *compactModeAct;
 	QAction *stayOnTopAct;
+	QAction *alternatesAct;		//ooo
 	QAction *wordStartsWithAct;	//ooo
 	QAction *wholeWordsOnlyAct;	//ooo
 	QAction *searchAllAct;		//ooo
 	QAction *searchEveryDictAct;	//ooo
+	QAction *lookUpInWholeStarDictAct;	//ooo
 	QAction *disableAct;
 	QAction *enableAct;
 
