@@ -144,6 +144,9 @@ Settings::Settings(QTrans *parent)
 	mouseSelection = new QCheckBox( "mouseSelection", label );	//ooo
 	mouseSelection->setText(i18n("Translate mouse selection"));
 
+	StatusBar = new QCheckBox( "StatusBar", label );	//ooo
+	StatusBar->setText(i18n("Enable Status Bar"));
+
 	miscLayout->addWidget(AutoPop);
 	miscLayout->addWidget(DontClose);
 	miscLayout->addWidget(DockIcon);
@@ -159,6 +162,7 @@ Settings::Settings(QTrans *parent)
 	miscLayout->addLayout(h2Layout);
 
 	miscLayout->addWidget(mouseSelection);
+	miscLayout->addWidget(StatusBar);			//ooo
 
 	//TextLabel3 = new QLabel("TextLabel3", label );
 	TextLabel3 = new QLabel("TextLabel3");
@@ -248,33 +252,33 @@ Settings::Settings(QTrans *parent)
 */
 	//QLabel *textLabel_Background= new QLabel(i18n("Background :"),this);
 	QLabel *textLabel_Background= new QLabel("TextLabel5", label);
-	textLabel_Background->setGeometry(QRect(20,40,110,20));
+	textLabel_Background->setGeometry(QRect(20,40,150,20));
 	textLabel_Background->setText(i18n("Background :"));
 	QLabel *textLabel_ExpressionText= new QLabel("TextLabel6", label);	//ooo
-	textLabel_ExpressionText->setGeometry(QRect(20,80,110,20));
+	textLabel_ExpressionText->setGeometry(QRect(20,80,150,20));
 	textLabel_ExpressionText->setText(i18n("Expression :"));
 	//QLabel *textLabel_Text= new QLabel(i18n("Text :"),this);
 	QLabel *textLabel_Text= new QLabel("TextLabel7", label);
 	//textLabel_Text->setGeometry(QRect(20,80,110,20));
-	textLabel_Text->setGeometry(QRect(20,120,110,20));			//ooo
+	textLabel_Text->setGeometry(QRect(20,120,150,20));			//ooo
 	//textLabel_Text->setText(i18n("Text :"));
 	textLabel_Text->setText(i18n("Definition :"));				//ooo
 	QLabel *textLabel_SentencePartText= new QLabel("TextLabel8", label);	//ooo
-	textLabel_SentencePartText->setGeometry(QRect(20,160,110,20));		//ooo
+	textLabel_SentencePartText->setGeometry(QRect(20,160,150,20));		//ooo
 	textLabel_SentencePartText->setText(i18n("Part of Language :"));	//ooo
 
 
 	//colorBtBack = new KColorButton(this);
 	colorBtBack = new KColorButton(label);
-	colorBtBack->setGeometry(QRect(140,35,280,30));
+	colorBtBack->setGeometry(QRect(170,35,280,30));
 	colorBtExpressionText = new KColorButton(label);	//ooo
-	colorBtExpressionText->setGeometry(QRect(140,75,280,30));
+	colorBtExpressionText->setGeometry(QRect(170,75,280,30));
 	//colorBtText = new KColorButton(this);
 	colorBtText = new KColorButton(label);
 	//colorBtText->setGeometry(QRect(140,75,280,30));
-	colorBtText->setGeometry(QRect(140,115,280,30));	//ooo
+	colorBtText->setGeometry(QRect(170,115,280,30));	//ooo
 	colorBtSentencePartText = new KColorButton(label);
-	colorBtSentencePartText->setGeometry(QRect(140,155,280,30));	//ooo
+	colorBtSentencePartText->setGeometry(QRect(170,155,280,30));	//ooo
 
 /*	topBox->addWidget(textLabel_Background);
 	topBox->addWidget(colorBtBack);
@@ -305,6 +309,16 @@ Settings::Settings(QTrans *parent)
 	if (Bab->Data->count()==0)
 		Bab->bRemoveAll->setEnabled(false);
 
+	QString strGoToLine = "";
+
+	for (int i = 1; i <= Bab->Data->count(); i++) {	//ooo
+		Bab->cGoToLine->addItem(strGoToLine.setNum(i));
+	}
+
+	//Bab->cGoToLine->setRange(5, 60);	//ooo
+
+	//Bab->cGoToLine->setMaxCount(Bab->Data->count());	//ooo
+
 	//dFont->setFont(parent->fontType);
 	chooseFont->setFont(parent->fontType);
 
@@ -345,6 +359,8 @@ Settings::Settings(QTrans *parent)
 	}
 	if (parent->MouseSelected)
 		mouseSelection->setChecked(true);
+	if (parent->StatusBarSelected)
+		StatusBar->setChecked(true);
 
 	if (parent->enableShortCut)
 		EnableShortCut->setChecked(true);
@@ -397,7 +413,8 @@ int Settings::slot_apply()
 	}
 
 	Par->fontType = chooseFont->font();
-	Par->Out->setFont(Par->fontType.family(),Par->fontType.pointSize(),Par->Charset);
+	//Par->Out->setFont(Par->fontType.family(),Par->fontType.pointSize(),Par->Charset);
+	Par->Out->setFont(Par->fontType.family(),Par->fontType.pointSize(),Par->fontType.style(),Par->fontType.weight(),Par->Charset);	//ooo
 	Par->Out->bgColor = colorBtBack->color().name();
 	Par->Out->txtColor = colorBtText->color().name();
 	Par->Out->expressionTxtColor = colorBtExpressionText->color().name();		//ooo
@@ -418,6 +435,15 @@ int Settings::slot_apply()
 	else
 		Par->MouseSelected = false;
 
+	if (StatusBar->isChecked()) {		//ooo
+		Par->StatusBarSelected = true;
+		Par->QMainWindow::statusBar()->show();
+		Par->QMainWindow::statusBar()->showMessage(tr("Ready"));
+	} else {
+		Par->StatusBarSelected = false;
+		Par->QMainWindow::statusBar()->hide();
+	}
+
 	if (DockIcon->isChecked()) {
 		Par->DockIcon = true;
 		Par->Dock->show();               //systemtray.cpp
