@@ -251,7 +251,7 @@ void Settings_widg::slot_Help()
 {
 	KMessageBox::information(this,
 		i18n("<qt>The default dictionary is the one on top of the list, "
-		"the others can be choosed from the popup menu in the main window.</qt>"),
+		"the others can be chosen from the popup menu in the main window.</qt>"),
 		i18n("Help"));
 }
 
@@ -987,6 +987,7 @@ void CAddWidget::slot_OpenFile()
                                "", tr("Engto*.dic | Babylon Dictionaries (*.dic)\n"
 				"*.bgl | Babylon Dictionaries (*.bgl)\n"
 				"*.dic.txt | Plain Text Dictionaries (*.dic.txt)\n"
+				"*.ifo | StarDict Dictionaries (*.ifo)\n"
 				"* | All files (*.*)"));
 	if (fileName != QString::null)
 		eFileName->setText(fileName);
