@@ -64,8 +64,10 @@ void QTrans::readConfig()
 		KWindowSystem::clearState(winId(),NET::SkipTaskbar);
 */
 	stayOnTop = cg.readEntry("stayOnTop",false);
+	enableAlternates = cg.readEntry("enableAlternates",false);		//ooo
 	wordStartsWith = cg.readEntry("wordStartsWith",false);			//ooo
 	wholeWordsOnly = cg.readEntry("wholeWordsOnly",false);			//ooo
+	wholeStarDict = cg.readEntry("wholeStarDict",false);			//ooo
 	this->resize(cg.readEntry("size",QSize(420, 120)));
 	ShortKey = cg.readEntry("ShortKey","CTRL+T");
 	closeAct = new KAction( this );
